import React, {
  useCallback,
  useRef,
  useEffect,
  useContext,
  useMemo
} from "react";
import { LinearProgress, Typography, Container, Stack } from "@mui/material";
import { Console } from "../common/Console/Console";
import { useSafePolling } from "../../hooks/Polling";
import { apiContext } from "../../api/DeployApi";
import { useAPIMethod } from "@ess-ics/ce-ui-common";

const LOG_POLL_INTERVAL = 5000;
export function DeploymentJobOutput({ deploymentJob }) {
  const client = useContext(apiContext);

  const params = useMemo(
    () => ({
      awx_job_id: deploymentJob?.id
    }),
    [deploymentJob]
  );

  const {
    value: log,
    wrapper: getLogById,
    loading: logLoading,
    dataReady: logDataReady,
    abort: abortGetLogById
  } = useAPIMethod({
    fcn: client.apis.Deployments.fetchDeploymentJobLog,
    params
  });

  const finalResultsNeeded = useRef(true);

  useEffect(() => {
    finalResultsNeeded.current = true;
  }, [deploymentJob.id]);

  const getLog = useCallback(() => {
    if (!deploymentJob.finished || finalResultsNeeded.current) {
      getLogById(deploymentJob.id);
      finalResultsNeeded.current = !deploymentJob.finished;
    }
  }, [deploymentJob.finished, deploymentJob.id, getLogById]);
  useSafePolling(
    getLog,
    logLoading || !logDataReady,
    LOG_POLL_INTERVAL,
    true,
    abortGetLogById
  );

  const dataReady = useCallback(() => {
    return deploymentJob?.started;
  }, [deploymentJob?.started]);

  let header = (
    <Stack
      flexDirection="row"
      alignItems="center"
      height="100%"
    >
      <Typography fontWeight="bold">DURATION: </Typography>
      <Typography marginLeft={"6px"}>{log?.elapsed.toFixed(0)} s</Typography>
    </Stack>
  );

  return (
    <Container maxWidth="xl">
      {log ? (
        <div
          style={{
            width: "100%"
          }}
        >
          <Console
            html={log.stdoutHtml}
            dataReady={dataReady}
            title="AWX job details"
            dialogHeader={header}
          />
        </div>
      ) : (
        <div style={{ width: "100%" }}>
          <LinearProgress color="primary" />
        </div>
      )}
    </Container>
  );
}
